/* This file is part of msolve.
 *
 * msolve is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 2 of the License, or
 * (at your option) any later version.
 *
 * msolve is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with msolve.  If not, see <https://www.gnu.org/licenses/>
 *
 * Authors:
 * Jérémy Berthomieu
 * Christian Eder
 * Mohab Safey El Din */


#ifndef LIBNEOGB_H
#define LIBNEOGB_H

#include "data.h"
#include "basis.h"
#include "engine.h"
#include "f4.h"
#include "sba.h"
#include "hash.h"
#include "io.h"
#include "modular.h"
#include "nf.h"
#include "f4sat.h"
#include "meta_data.h"
#include "sort_r.h"
#include "tools.h"
#include "update.h"

#endif
